{ config, pkgs, ... }:

{
  imports =
    [
      ./common-headless.nix
    ];

  # Use the GRUB 2 boot loader.
  boot.loader.grub.enable = true;
  boot.loader.grub.version = 2;
  boot.loader.grub.zfsSupport = true;
  boot.supportedFilesystems = ["zfs"];
  # boot.loader.grub.efiSupport = true;
  # boot.loader.grub.efiInstallAsRemovable = true;
  # boot.loader.efi.efiSysMountPoint = "/boot/efi";
  # Define on which hard drive you want to install Grub.
  # boot.loader.grub.device = "/dev/sda"; # or "nodev" for efi only
  boot.loader.grub.mirroredBoots = [
    { devices = [ "/dev/sda" ]; path = "/boota"; }
    { devices = [ "/dev/sdb" ]; path = "/bootb"; }
    { devices = [ "/dev/sdc" ]; path = "/bootc"; }
    { devices = [ "/dev/sdd" ]; path = "/bootd"; }
    { devices = [ "/dev/sde" ]; path = "/boote"; }
    { devices = [ "/dev/sdf" ]; path = "/bootf"; }
  ];

  networking.hostName = "aplysia"; # Define your hostname.
  networking.hostId = "34a820f1";

  services.openssh.enable = true;

  users.extraUsers.gebner = {
    isNormalUser = true;
    extraGroups = ["wheel"];
  };
  
  boot.kernelPackages = pkgs.lib.mkOverride 10 pkgs.linuxPackages;

  # The NixOS release to be compatible with for stateful data such as databases.
  system.stateVersion = "17.03";

}
